@@ -21,7 +21,8 @@ debug_enabled = os.getenv('PYBRITIVE_DEBUG')
 
 
 class BritiveCli:
-    def __init__(self, tenant_name: str = None, token: str = None, silent: bool = False, passphrase: str = None):
+    def __init__(self, tenant_name: str = None, token: str = None, silent: bool = False,
+                 passphrase: str = None, federation_provider: str = None):
         self.silent = silent
         self.output_format = None
         self.tenant_name = None
@@ -32,6 +33,7 @@ class BritiveCli:
         self.config = ConfigManager(tenant_name=tenant_name, cli=self)
         self.list_separator = '|'
         self.passphrase = passphrase
+        self.federation_provider = federation_provider
         self.credential_manager = None
 
     def set_output_format(self, output_format: str):
@@ -45,14 +47,16 @@ class BritiveCli:
             self.credential_manager = FileCredentialManager(
                 tenant_alias=self.tenant_alias,
                 tenant_name=self.tenant_name,
-                cli=self
+                cli=self,
+                federation_provider=self.federation_provider
             )
         elif backend == 'encrypted-file':
             self.credential_manager = EncryptedFileCredentialManager(
                 tenant_alias=self.tenant_alias,
                 tenant_name=self.tenant_name,
                 cli=self,
-                passphrase=self.passphrase
+                passphrase=self.passphrase,
+                federation_provider=self.federation_provider
             )
         else:
             raise click.ClickException(f'invalid credential backend {backend}.')
@@ -251,7 +255,7 @@ class BritiveCli:
         raise click.ClickException(f'Application {application_id} not found')
 
     def __get_cloud_credential_printer(self, app_type, console, mode, profile, silent, credentials,
-                                       aws_credentials_file):
+                                       aws_credentials_file, gcloud_key_file):
         if app_type in ['AWS', 'AWS Standalone']:
             return printer.AwsCloudCredentialPrinter(
                 console=console,
@@ -278,7 +282,8 @@ class BritiveCli:
                 profile=profile,
                 credentials=credentials,
                 silent=silent,
-                cli=self
+                cli=self,
+                gcloud_key_file=gcloud_key_file
             )
         else:
             return printer.GenericCloudCredentialPrinter(
@@ -344,7 +349,7 @@ class BritiveCli:
         return parts_dict
 
     def checkout(self, alias, blocktime, console, justification, mode, maxpolltime, profile, passphrase,
-                 force_renew, aws_credentials_file):
+                 force_renew, aws_credentials_file, gcloud_key_file):
         credentials = None
         app_type = None
         credential_process_creds_found = False
@@ -414,7 +419,8 @@ class BritiveCli:
             alias or profile,
             self.silent,
             credentials,
-            aws_credentials_file
+            aws_credentials_file,
+            gcloud_key_file
         ).print()
 
     def import_existing_npm_config(self):
@@ -555,6 +561,9 @@ class BritiveCli:
             application_name=parts['app']
         )
 
+    def clear_gcloud_auth_key_files(self):
+        self.config.clear_gcloud_auth_key_files()
+
 
 
 
