@@ -11,32 +11,32 @@ def ls():
 
 @ls.command()
 @build_britive
-@britive_options(names='format,tenant,token,passphrase')
-def applications(ctx, output_format, tenant, token, passphrase):
+@britive_options(names='format,tenant,token,passphrase,federation_provider')
+def applications(ctx, output_format, tenant, token, passphrase, federation_provider):
     """List applications for the currently authenticated identity."""
     ctx.obj.britive.list_applications()
 
 
 @ls.command()
 @build_britive
-@britive_options(names='format,tenant,token,passphrase')
-def environments(ctx, output_format, tenant, token, passphrase):
+@britive_options(names='format,tenant,token,passphrase,federation_provider')
+def environments(ctx, output_format, tenant, token, passphrase, federation_provider):
     """List environments for the currently authenticated identity."""
     ctx.obj.britive.list_environments()
 
 
 @ls.command()
 @build_britive
-@britive_options(names='checked_out,output_format,tenant,token,passphrase')
-def profiles(ctx, checked_out, output_format, tenant, token, passphrase):
+@britive_options(names='checked_out,output_format,tenant,token,passphrase,federation_provider')
+def profiles(ctx, checked_out, output_format, tenant, token, passphrase, federation_provider):
     """List profiles for the currently authenticated identity."""
     ctx.obj.britive.list_profiles(checked_out=checked_out)
 
 
 @ls.command()
 @build_britive
-@britive_options(names='format,tenant,token,passphrase')
-def secrets(ctx, output_format, tenant, token, passphrase):
+@britive_options(names='format,tenant,token,passphrase, federation_provider')
+def secrets(ctx, output_format, tenant, token, passphrase, federation_provider):
     """List secrets for the currently authenticated identity."""
     ctx.obj.britive.list_secrets()
 
